@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 use 5.024;
-use feature qw /postderef signatures switch/;
+use feature qw /postderef signatures/;
 
 package Vote::Count::Charge;
 use namespace::autoclean;
@@ -16,11 +16,11 @@ use Data::Dumper;
 use Time::Piece;
 use Path::Tiny;
 use Carp;
-use JSON::MaybeXS;
+use Cpanel::JSON::XS;
 use YAML::XS;
 # use Storable 3.15 'dclone';
 
-our $VERSION='1.214';
+our $VERSION='2.04';
 
 has 'Seats' => (
   is       => 'ro',
@@ -157,7 +157,7 @@ sub VCUpdateActive ($I) {
   my $active = {};
   for my $k ( keys $I->GetChoiceStatus()->%* ) {
     $active->{$k} = 1 if $I->{'choice_status'}->{$k}{'state'} eq 'hopeful';
-    $active->{$k} = 1 if $I->{'choice_status'}->{$k}{'state'} eq 'pending';
+    # $active->{$k} = 1 if $I->{'choice_status'}->{$k}{'state'} eq 'pending';
   }
   $I->SetActive($active);
 }
@@ -246,12 +246,10 @@ sub Reinstate ( $I, @choices ) {
   my @reinstated = ();
 REINSTATELOOP:
   for my $choice (@choices) {
-  # I'm a fan of the give/when construct, but go to lengths not to use it
-  # because of past issues and that after 15 years it is still experimental.
-    given ($I->{'choice_status'}{$choice}{'state'}){
-      when ( 'suspended') { }
-      when ( 'deferred' )  { }
-      default { next REINSTATELOOP }
+    for my $state ($I->{'choice_status'}{$choice}{'state'}){
+      if ( $state eq 'suspended') { }
+      elsif ( $state eq 'deferred' )  { }
+      else { next REINSTATELOOP }
     };
     ($I->{'suspended'}->@*) = grep ( !/^$choice$/, $I->{'suspended'}->@* );
     ($I->{'deferred'}->@*) = grep ( !/^$choice$/, $I->{'deferred'}->@* );
@@ -316,7 +314,7 @@ sub WriteSTVEvent( $I) {
   my $jsonpath = $I->LogTo . '_stvevents.json';
   my $yamlpath = $I->LogTo . '_stvevents.yaml';
   # my $yaml = ;
-  my $coder = JSON->new->ascii->pretty;
+  my $coder = Cpanel::JSON::XS->new->ascii->pretty;
   path($jsonpath)->spew( $coder->encode( $I->STVEvent() ) );
   path($yamlpath)->spew( Dump $I->STVEvent() );
 }
@@ -377,7 +375,7 @@ sub SetQuota ($I, $style='droop') {
 
 Vote::Count::Charge
 
-=head1 VERSION 1.214
+=head1 VERSION 2.04
 
 =cut
 
@@ -457,7 +455,7 @@ Takes the arguments of a Choice and a hashref with the keys 'state' and 'votes'.
 
 =head3 VCUpdateActive
 
-Update the ActiveSet of the underlying Vote::Count object to match the set of Choices that are currently 'hopeful' or 'pending'.
+Update the ActiveSet of the underlying Vote::Count object to match the set of Choices that are currently 'hopeful'.
 
 =head2 Elected and Pending
 
